==> fabric_user_data_functions-0.2.6rc0.tar.gz: fabric_user_data_functions-0.2.6rc0/fabric/functions/internal/item_binding.py <==
import json
from typing import Any, Optional

# flake8: noqa: I900
import azure
from azure.functions.decorators.core import DataType, InputBinding

from fabric.functions.internal.fabric_item import FabricItem
from fabric.functions.udf_exception import UserDataFunctionInternalError

from ..fabric_class import (FabricLakehouseFilesClient,
                           FabricSqlConnection, FabricLakehouseClient)

# The binding object that will be used by our input decorator below
class FabricItemInput(InputBinding):
    @staticmethod
    def get_binding_name() -> str:
        return 'FabricItem'
    
    def __init__(self,
                name: str,
                alias: str,
                **kwargs):
        super().__init__(name, DataType.STRING)

# The input converter that automatically gets registered in the function app. 
class FabricItemConverter(azure.functions.meta.InConverter,
                              binding='FabricItem'):

    @classmethod
    def check_input_type_annotation(cls, pytype: type) -> bool:

        # Need to check what the enum type of the item is and make sure we can convert it
        return issubclass(pytype, (FabricItem, FabricSqlConnection))
    
    @classmethod
    def parseType(self, body: json):

        endpoints = body['Endpoints']
        endpoints = {k.lower():v for k,v in endpoints.items()} # we can know this doesn't have collisions 
        # because the host extension uses a case insensitive dictionary
        sqlEndpoint = "sqlendpoint"
        fileEndpoint = "fileendpoint"


        if sqlEndpoint in endpoints and fileEndpoint in endpoints:
            return FabricLakehouseClient(
                alias_name=body['AliasName'],
                endpoints=endpoints)
        elif sqlEndpoint in endpoints:
            return FabricSqlConnection(
                alias_name=body['AliasName'],
                endpoints=endpoints)
        elif fileEndpoint in endpoints:
            return FabricLakehouseFilesClient(
                alias_name=body['AliasName'],
                endpoints=endpoints)

        # If not found above, return the default
        return FabricItem(
                alias_name=body['AliasName'],
                endpoints=endpoints)
    
    @classmethod
    def decode(cls, data, *,
               trigger_metadata) -> Any:
        if data is not None and data.type == 'string' and data.value is not None: 
            body = json.loads(data.value)
            error = body.get('ErrorMessage', None)
            if error:
                return UserDataFunctionInternalError(
                    f'Unable to load data successfully for fabric item', {'reason': error})
        else:
            return UserDataFunctionInternalError(
                f'Unable to load data successfully for fabric item')

        return cls.parseType(body)

==> fabric_user_data_functions-0.2.8rc0.tar.gz: fabric_user_data_functions-0.2.8rc0/fabric/functions/internal/item_binding.py <==
import json
from typing import Any, Optional

# flake8: noqa: I900
import azure
from azure.functions.decorators.core import DataType, InputBinding

from fabric.functions.internal.fabric_item import FabricItem
from fabric.functions.internal.fabric_lakehouse_files_client import FabricLakehouseFilesClient
from fabric.functions.udf_exception import UserDataFunctionInternalError

from ..fabric_class import (FabricSqlConnection, FabricLakehouseClient)

# The binding object that will be used by our input decorator below
class FabricItemInput(InputBinding):
    @staticmethod
    def get_binding_name() -> str:
        return 'FabricItem'
    
    def __init__(self,
                name: str,
                alias: str,
                **kwargs):
        super().__init__(name, DataType.STRING)

# The input converter that automatically gets registered in the function app. 
class FabricItemConverter(azure.functions.meta.InConverter,
                              binding='FabricItem'):

    @classmethod
    def check_input_type_annotation(cls, pytype: type) -> bool:

        # Need to check what the enum type of the item is and make sure we can convert it
        return issubclass(pytype, (FabricItem, FabricSqlConnection))
    
    @classmethod
    def parseType(self, body: json):

        endpoints = body['Endpoints']
        endpoints = {k.lower():v for k,v in endpoints.items()} # we can know this doesn't have collisions 
        # because the host extension uses a case insensitive dictionary
        sqlEndpoint = "sqlendpoint"
        fileEndpoint = "fileendpoint"


        if sqlEndpoint in endpoints and fileEndpoint in endpoints:
            return FabricLakehouseClient(
                alias_name=body['AliasName'],
                endpoints=endpoints)
        elif sqlEndpoint in endpoints:
            return FabricSqlConnection(
                alias_name=body['AliasName'],
                endpoints=endpoints)
        elif fileEndpoint in endpoints:
            return FabricLakehouseFilesClient(
                alias_name=body['AliasName'],
                endpoints=endpoints)

        # If not found above, return the default
        return FabricItem(
                alias_name=body['AliasName'],
                endpoints=endpoints)
    
    @classmethod
    def decode(cls, data, *,
               trigger_metadata) -> Any:
        if data is not None and data.type == 'string' and data.value is not None: 
            body = json.loads(data.value)
            error = body.get('ErrorMessage', None)
            if error:
                return UserDataFunctionInternalError(
                    f'Unable to load data successfully for fabric item', {'reason': error})
        else:
            return UserDataFunctionInternalError(
                f'Unable to load data successfully for fabric item')

        return cls.parseType(body)
